@@ -11,7 +11,7 @@ sub bi_env
 	foreach my $key (sort keys %ENV) {
 		Psh::Util::print_out("$key=$ENV{$key}\n");
 	}
-	return undef;
+	return (1,undef);
 }
 
 1;
