@@ -1,7 +1,6 @@
 package Psh::Builtins::History;
-use strict;
 
-use Psh::Util ':all';
+require Psh::Util;
 
 =item * C<history> [n]
 
@@ -21,7 +20,7 @@ sub bi_history
 	my $num = @Psh::history;
 	my $grep= undef;
 
-	return undef unless $num;
+	return (0,undef) unless $num;
 
 	if ($_[1]) {
 		my @args=@{$_[1]};
@@ -35,11 +34,17 @@ sub bi_history
 		}
 	}
 
-	for ($i=@Psh::history-$num; $i<@Psh::history; $i++) {
-		next if $grep and $Psh::history[$i]!~/\Q$grep\E/;
-		print_out(' '.sprintf('%3d',$i+1).'  '.$Psh::history[$i]."\n");
+	my $success=0;
+	my $max= @Psh::history;
+	if ($grep) {
+		$max--;
 	}
-	return undef;
+	for ($i=@Psh::history-$num; $i<$max; $i++) {
+		next if $grep and $Psh::history[$i]!~/\Q$grep\E/;
+		Psh::Util::print_out(' '.sprintf('%3d',$i+1).'  '.$Psh::history[$i]."\n");
+		$success=1;
+	}
+	return ($success,undef);
 }
 
 
